# This script will compile the binary and launch a job
# that will report the FLOPs of the kernel defined in
# src/kernel.f90 and make a plot.

function checkbinary(){
   if [ ! -f bin/elemental.x ];then
      echo 1
   else
      echo 0
   fi
   }

function job_status(){
    while  [ 1 -gt 0 ];do
       if [ $(bjobs $1 2>&1 | grep "not found" -c ) -gt 0 ];then
          echo -en "\033[1K\rJob not found yet"
       else
          if [  $(bjobs $1 | grep  "PEND" -c ) -gt 0 ];then
             echo -en "\033[1K\rJob waiting..."
          fi
          if [  $(bjobs $1 | grep  "RUN" -c ) -gt 0 ];then
             echo -en "\033[1K\rJob running..."
          fi
          if [  $(bjobs $1 | grep  "DONE" -c ) -gt 0 ];then
             echo -e "\033[1K\rJob finished..."
             return 0
          fi
       fi
       sleep 1
    done
}


# (Re)Compiling-----------------------------------------
echo -n "Compiling..."

if [ ! -d bin ]; then
   mkdir bin
fi

utils/compile.sh &> /dev/null
if [ $(checkbinary) -eq 1 ];then
   echo "It did not compile well. Recompiling with output..."
   echo
   utils/compile.sh 
   exit 1
else 
   echo -e "\033[1K\r\n\nCompiled!"
fi
#-------------------------------------------------------


#-------------------------------------------------------
#Measuring FlopsPerByte

FpB=$(python utils/PythonScripts/FlopsPerByteInKernel.py src/kernels.f90)
echo
echo "The current kernel has a computational intensity of $FpB FlopsPerByte"
echo

# Launching test ---------------------------------------
# Entering to folder
cd utils
# Loading the proper environment ----------------
source compilation.env &> /dev/null
module load extrae &> /dev/null
# Launching all the different cases for array size
# in one core ------------------------------------------

# Calculate how much memory for array element is being used
MemoryFactor=$(python PythonScripts/MemoryUsedInKernel.py ../src/kernels.f90)

n=1
for i in {9..21};do
   num=$((2**$i))
   extrae_wrapper.sh ../bin/elemental.x $num &> /dev/null
   mpi2prv -f TRACE.mpits -e ../bin/elemental.x -o tmp.prv &> /dev/null
   echo -n "$n $(($num * $MemoryFactor)) "
   python PythonScripts/get_events.py tmp.prv
   rename tmp. trace_n${n}_i${num}. tmp.*
done > .tmp.log
# Ploting the results ----------------------------
module purge &> /dev/null
module load python/2.7.6 &> /dev/null
module load mkl  &> /dev/null

FpB=$(python PythonScripts/FlopsPerByteInKernel.py ../src/kernels.f90)
python PythonScripts/PeakPercentage.py .tmp.log $FpB &> /dev/null
python PythonScripts/PerformanceReport.py .tmp.log $FpB &> /dev/null
# Cleaning ----------------------------------------
rm -rf set-* *prv *row *pcf TRACE.*
# ------------------------------------------------
mv percentage.png ../percentage.png
mv report.txt ..

cd ..
# Remove temporary file
rm utils/.tmp.log
cat report.txt
display percentage.png & 
#-------------------------------------------------------
